@@ -3,7 +3,6 @@ import datetime
 import logging
 import json
 import uuid
-import unicodedata
 import hashlib
 import base64
 import traceback
@@ -369,8 +368,7 @@ class Worker:
     def _preprocess(text):
         return text.replace("\xa0", " ").replace("&nbsp;", " ").strip()
 
-    @staticmethod
-    def _read_blob_by_segments(input_blob):
+    def _read_blob_by_segments(self, input_blob):
         blob_data = input_blob.download_blob()
         last_piece = ""
         for chunk in blob_data.chunks():
@@ -378,15 +376,15 @@ class Worker:
             lines[0] = last_piece + lines[0]
             last_piece = lines[-1]
             for l in lines[:-1]:
-                l = unicodedata.normalize("NFKD", l).strip()
+                l = self._preprocess(l)
                 if len(l) == 0:
                     continue
-                source_segment = json.loads(l)[0].strip()
+                source_segment = self._preprocess(json.loads(l)[0])
                 yield source_segment
 
-        last_piece = unicodedata.normalize("NFKD", last_piece).strip()
+        last_piece = self._preprocess(last_piece)
         if len(last_piece) > 0:
-            source = json.loads(last_piece)[0].strip()
+            source = self._preprocess(json.loads(last_piece)[0])
             yield source
 
     @staticmethod
